﻿#region LICENSE
//
// Copyright (c) Microncode.com
// 
// This source is subject to the Microsoft Public License. 
// See https://opensource.org/licenses/ms-pl.html.
// All other rights reserved. 
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE. 
//
#endregion

namespace CSDVDCDBurnerExample
{
    using System;
    using System.Windows.Forms;

    /// <summary>
    /// The main example of using the CSDVDCDBurner library.
    /// </summary>
    public partial class frmDVDCDBurner : Form
    {
        private CSDVDCDBurner.DVDCDBurner dvdcdBurner1;

        /// <summary>
        /// Constructor.
        /// </summary>
        public frmDVDCDBurner()
        {
            InitializeComponent();

            this.dvdcdBurner1 = new CSDVDCDBurner.DVDCDBurner();

            this.dvdcdBurner1.BurnStatus += new CSDVDCDBurner.DVDCDBurner.BurnStatusEventHandler(this.dvdcdBurner1_BurnStatus);
            this.dvdcdBurner1.BurnStart += new CSDVDCDBurner.DVDCDBurner.BurnStartEventHandler(this.dvdcdBurner1_BurnStart);
            this.dvdcdBurner1.BurnValidating += new CSDVDCDBurner.DVDCDBurner.BurnValidatingEventHandler(this.dvdcdBurner1_BurnValidating);
            this.dvdcdBurner1.BurnFormatting += new CSDVDCDBurner.DVDCDBurner.BurnFormattingEventHandler(this.dvdcdBurner1_BurnFormatting);
            this.dvdcdBurner1.BurnInitializing += new CSDVDCDBurner.DVDCDBurner.BurnInitializingEventHandler(this.dvdcdBurner1_BurnInitializing);
            this.dvdcdBurner1.BurnOptimizing += new CSDVDCDBurner.DVDCDBurner.BurnOptimizingEventHandler(this.dvdcdBurner1_BurnOptimizing);
            this.dvdcdBurner1.BurnProgress += new CSDVDCDBurner.DVDCDBurner.BurnProgressEventHandler(this.dvdcdBurner1_BurnProgress);
            this.dvdcdBurner1.BurnFinalizing += new CSDVDCDBurner.DVDCDBurner.BurnFinalizingEventHandler(this.dvdcdBurner1_BurnFinalizing);
            this.dvdcdBurner1.BurnCompleted += new CSDVDCDBurner.DVDCDBurner.BurnCompletedEventHandler(this.dvdcdBurner1_BurnCompleted);
            this.dvdcdBurner1.BurnVerifying += new CSDVDCDBurner.DVDCDBurner.BurnVerifyingEventHandler(this.dvdcdBurner1_BurnVerifying);
            this.dvdcdBurner1.BurnCancelled += new CSDVDCDBurner.DVDCDBurner.BurnCancelledEventHandler(this.dvdcdBurner1_BurnCancelled);
            this.dvdcdBurner1.BurnFinished += new CSDVDCDBurner.DVDCDBurner.BurnFinishedEventHandler(this.dvdcdBurner1_BurnFinished);
            this.dvdcdBurner1.BurnError += new CSDVDCDBurner.DVDCDBurner.BurnErrorEventHandler(this.dvdcdBurner1_BurnError);
        }

        /// <summary>
        /// Form load.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void frmDVDCDBurner_Load(object sender, EventArgs e)
        {
            dvdcdBurner1.UserName = "Your email";
            dvdcdBurner1.UserKey = "Your registration key";

            //Get all the drives:
            foreach (CSDVDCDBurner.DriveInfo cDriveInfo in dvdcdBurner1.DrivesInfo)
            {
                comboDrives.Items.Add(cDriveInfo.Name);
            }

            comboDrives.SelectedIndex = 0;
            cmboVerification.SelectedIndex = 0;
        }

        /// <summary>
        /// Open the drive door.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnOpen_Click(object sender, EventArgs e)
        {
            dvdcdBurner1.DriveOpen(comboDrives.SelectedIndex);
        }

        /// <summary>
        /// Close the drive door.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnClose_Click(object sender, EventArgs e)
        {
            dvdcdBurner1.DriveClose(comboDrives.SelectedIndex);
        }

        /// <summary>
        /// Add files to the list to burn.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnAddFiles_Click(object sender, EventArgs e)
        {
            if ((OpenFileDialog1.ShowDialog(this) == DialogResult.OK))
            {
                //Add a file to the list to burn:
                dvdcdBurner1.AddFile(OpenFileDialog1.FileName);
                lstItems.Items.Add(OpenFileDialog1.FileName);
                lstItems.SelectedIndex = lstItems.Items.Count - 1;

            }
        }

        /// <summary>
        /// Add directory to the list to burn.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnAddDir_Click(object sender, EventArgs e)
        {
            string sDirName = null;
            
            if ((FolderBrowserDialog1.ShowDialog(this) == DialogResult.OK))
            {
                sDirName = FolderBrowserDialog1.SelectedPath;

                //Dir path must ended with '\'
                sDirName = sDirName + "\\";

                //Add a directory to the list to burn:
                dvdcdBurner1.AddDir(sDirName);
                lstItems.Items.Add(sDirName);
                lstItems.SelectedIndex = lstItems.Items.Count - 1;

            }
        }

        /// <summary>
        /// Remove file / directory from the list to burn.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnRemove_Click(object sender, EventArgs e)
        {
            if ((MessageBox.Show("Remove " + lstItems.SelectedItem + " ?", "Remove item", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes))
            {
                dvdcdBurner1.RemoveFileDir(lstItems.SelectedItem.ToString());
                lstItems.Items.Remove(lstItems.SelectedItem);

            }
        }

        /// <summary>
        /// Clear the list to burn.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnClear_Click(object sender, EventArgs e)
        {
            dvdcdBurner1.ClearFilesDirs();
            lstItems.Items.Clear();
        }

        /// <summary>
        /// Burn.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnBurn_Click(object sender, EventArgs e)
        {
            if (lstItems.Items.Count == 0)
            {
                MessageBox.Show("The items list is empty");
                return;
            }

            if (dvdcdBurner1.IsMediaReady(comboDrives.SelectedIndex) == 0)
            {
                AddToStatus("Preparing... Please wait");
                dvdcdBurner1.Burn(comboDrives.SelectedIndex, txtMediaLable.Text, chkCloseMedia.Checked, chkEject.Checked);
            }
            else
            {
                MessageBox.Show("Drive or media is not ready");
            }
        }

        /// <summary>
        /// Cancel.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCancel_Click(object sender, EventArgs e)
        {
            dvdcdBurner1.BurnCancel();
        }

        /// <summary>
        /// The media type.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnMediaType_Click(object sender, EventArgs e)
        {
            MessageBox.Show(dvdcdBurner1.MediaType(comboDrives.SelectedIndex));
        }

        /// <summary>
        /// The media size.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnMediaSize_Click(object sender, EventArgs e)
        {
            lblMedia.Text = dvdcdBurner1.MediaSizeString(comboDrives.SelectedIndex) + " (" + dvdcdBurner1.MediaSize(comboDrives.SelectedIndex) + " bytes)";
        }

        /// <summary>
        /// Capability.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCapability_Click(object sender, EventArgs e)
        {
            MessageBox.Show(dvdcdBurner1.DrivesInfo[comboDrives.SelectedIndex].Capability);
        }

        /// <summary>
        /// Print to the status bar.
        /// </summary>
        /// <param name="sStr"></param>
        private void AddToStatus(string sStr)
        {
            lblStatus.Text = sStr.Trim();
        }

        //Events:

        private void dvdcdBurner1_BurnCancelled()
        {
            AddToStatus("BurnCancelled");
        }

        private void dvdcdBurner1_BurnCompleted()
        {
            AddToStatus("BurnCompleted");
        }

        private void dvdcdBurner1_BurnError(string Message)
        {
            AddToStatus("Error: " + Message);
        }

        private void dvdcdBurner1_BurnFinalizing()
        {
            prgProgress.Value = 100;
            AddToStatus("BurnFinalizing");
        }

        private void dvdcdBurner1_BurnFinished()
        {
            AddToStatus("BurnFinished");
        }

        private void dvdcdBurner1_BurnFormatting()
        {
            AddToStatus("BurnFormatting");
        }

        private void dvdcdBurner1_BurnInitializing()
        {
            AddToStatus("BurnInitializing");
        }

        private void dvdcdBurner1_BurnOptimizing()
        {
            AddToStatus("BurnOptimizing");
        }

        private void dvdcdBurner1_BurnProgress(long Percent)
        {
            prgProgress.Value = (int)Percent;
        }

        private void dvdcdBurner1_BurnStart()
        {
            AddToStatus("BurnStart");
        }

        private void dvdcdBurner1_BurnStatus(string Message)
        {
            AddToStatus("BurnStatus:" + Message);
        }

        private void dvdcdBurner1_BurnValidating()
        {
            AddToStatus("BurnValidating");
        }

        private void dvdcdBurner1_BurnVerifying()
        {
            AddToStatus("BurnVerifying");
        }

        /// <summary>
        /// Order a license.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cmdOrderLicense_Click(object sender, EventArgs e)
        {
            /// In order to get your own UserName and RegKey and to distribute this library
            /// with your own projects for commercial or any other purpose, please order a license at:
            /// https://www.microncode.com/developers/cs-dvd-cd-burner/?cmd=order

            System.Diagnostics.Process.Start("https://www.microncode.com/developers/cs-dvd-cd-burner/?cmd=order");
        }
    }
}
