﻿#Region "LICENSE"
'
' Copyright (c) Microncode.com
' 
' This source is subject to the Microsoft Public License. 
' See https://opensource.org/licenses/ms-pl.html.
' All other rights reserved. 
' 
' THIS CODE And INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED Or IMPLIED, INCLUDING BUT Not LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY And/Or FITNESS FOR A PARTICULAR PURPOSE. 
'
#End Region

''' <summary>
''' The main example of using the CSDVDCDBurner library.
''' </summary>
Public Class frmDVDCDBurner

    Friend WithEvents DvdcdBurner1 As CSDVDCDBurner.DVDCDBurner
    ''' <summary>
    ''' Form load.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub frmDVDCDBurner_Load(sender As Object, e As EventArgs) Handles MyBase.Load

        Me.DvdcdBurner1 = New CSDVDCDBurner.DVDCDBurner()

        DvdcdBurner1.UserName = "Your email"
        DvdcdBurner1.UserKey = "Your registration key"

        For Each cDriveInfo As CSDVDCDBurner.DriveInfo In DvdcdBurner1.DrivesInfo
            comboDrives.Items.Add(cDriveInfo.Name)
        Next

        comboDrives.SelectedIndex = 0
        cmboVerification.SelectedIndex = 0

    End Sub

    ''' <summary>
    ''' Open the drive door.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnOpen_Click(sender As Object, e As EventArgs) Handles btnOpen.Click

        DvdcdBurner1.DriveOpen(comboDrives.SelectedIndex)

    End Sub

    ''' <summary>
    ''' Close the drive door.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnClose_Click(sender As Object, e As EventArgs) Handles btnClose.Click

        DvdcdBurner1.DriveClose(comboDrives.SelectedIndex)

    End Sub

    ''' <summary>
    ''' Add files to the list to burn.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnAddFiles_Click(sender As Object, e As EventArgs) Handles btnAddFiles.Click

        If (OpenFileDialog1.ShowDialog(Me) = DialogResult.OK) Then
            DvdcdBurner1.AddFile(OpenFileDialog1.FileName)
            lstItems.Items.Add(OpenFileDialog1.FileName)
            lstItems.SelectedIndex = lstItems.Items.Count - 1
        End If

    End Sub

    ''' <summary>
    ''' Add directory to the list to burn.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnAddDir_Click(sender As Object, e As EventArgs) Handles btnAddDir.Click

        Dim sDirName As String = Nothing

        If (FolderBrowserDialog1.ShowDialog(Me) = DialogResult.OK) Then

            sDirName = FolderBrowserDialog1.SelectedPath

            'Dir path must ended with '\'
            sDirName = sDirName & "\"

            DvdcdBurner1.AddDir(sDirName)
            lstItems.Items.Add(sDirName)
            lstItems.SelectedIndex = lstItems.Items.Count - 1

        End If

    End Sub

    ''' <summary>
    ''' Remove file / directory from the list to burn.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnRemove_Click(sender As Object, e As EventArgs) Handles btnRemove.Click

        If (MessageBox.Show("Remove " & lstItems.SelectedItem & " ?", "Remove item", MessageBoxButtons.YesNo, MessageBoxIcon.Question) = DialogResult.Yes) Then
            DvdcdBurner1.RemoveFileDir(lstItems.SelectedItem.ToString())
            lstItems.Items.Remove(lstItems.SelectedItem)
        End If

    End Sub

    ''' <summary>
    ''' Clear the list to burn.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnClear_Click(sender As Object, e As EventArgs) Handles btnClear.Click

        DvdcdBurner1.ClearFilesDirs()
        lstItems.Items.Clear()

    End Sub

    ''' <summary>
    ''' Burn.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnBurn_Click(sender As Object, e As EventArgs) Handles btnBurn.Click

        If lstItems.Items.Count = 0 Then
            MessageBox.Show("The items list is empty")
            Return
        End If

        If DvdcdBurner1.IsMediaReady(comboDrives.SelectedIndex) = 0 Then
            AddToStatus("Preparing... Please wait")
            DvdcdBurner1.Burn(comboDrives.SelectedIndex, txtMediaLable.Text, chkCloseMedia.Checked, chkEject.Checked)
        Else
            MessageBox.Show("Drive or media is not ready")
        End If

    End Sub

    ''' <summary>
    ''' Cancel.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnCancel_Click(sender As Object, e As EventArgs) Handles btnCancel.Click

        DvdcdBurner1.BurnCancel()

    End Sub

    ''' <summary>
    ''' The media type.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnMediaType_Click(sender As Object, e As EventArgs) Handles btnMediaType.Click

        MessageBox.Show(DvdcdBurner1.MediaType(comboDrives.SelectedIndex))

    End Sub

    ''' <summary>
    ''' The media size.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnMediaSize_Click(sender As Object, e As EventArgs) Handles btnMediaSize.Click

        lblMedia.Text = DvdcdBurner1.MediaSizeString(comboDrives.SelectedIndex) & " (" & DvdcdBurner1.MediaSize(comboDrives.SelectedIndex) & " bytes)"

    End Sub

    ''' <summary>
    ''' Capability.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnCapability_Click(sender As Object, e As EventArgs) Handles btnCapability.Click

        MessageBox.Show(DvdcdBurner1.DrivesInfo(comboDrives.SelectedIndex).Capability)

    End Sub

    ''' <summary>
    ''' Print to the status bar.
    ''' </summary>
    ''' <param name="sStr"></param>
    Private Sub AddToStatus(ByVal sStr As String)

        lblStatus.Text = sStr.Trim()

    End Sub

    'Events:

    Private Sub DvdcdBurner1_BurnCancelled() Handles DvdcdBurner1.BurnCancelled
        AddToStatus("BurnCancelled")
    End Sub

    Private Sub DvdcdBurner1_BurnCompleted() Handles DvdcdBurner1.BurnCompleted
        AddToStatus("BurnCompleted")
    End Sub

    Private Sub DvdcdBurner1_BurnError(Message As String) Handles DvdcdBurner1.BurnError
        AddToStatus("Error: " & Message)
    End Sub

    Private Sub DvdcdBurner1_BurnFinalizing() Handles DvdcdBurner1.BurnFinalizing
        prgProgress.Value = 100
    End Sub

    Private Sub DvdcdBurner1_BurnFinished() Handles DvdcdBurner1.BurnFinished
        AddToStatus("BurnFinished")
    End Sub

    Private Sub DvdcdBurner1_BurnFormatting() Handles DvdcdBurner1.BurnFormatting
        AddToStatus("BurnFormatting")
    End Sub

    Private Sub DvdcdBurner1_BurnInitializing() Handles DvdcdBurner1.BurnInitializing
        AddToStatus("BurnInitializing")
    End Sub

    Private Sub DvdcdBurner1_BurnOptimizing() Handles DvdcdBurner1.BurnOptimizing
        AddToStatus("BurnOptimizing")
    End Sub

    Private Sub DvdcdBurner1_BurnProgress(Percent As Long) Handles DvdcdBurner1.BurnProgress
        prgProgress.Value = CInt(Percent)
    End Sub

    Private Sub DvdcdBurner1_BurnStart() Handles DvdcdBurner1.BurnStart
        AddToStatus("BurnStart")
    End Sub

    Private Sub DvdcdBurner1_BurnStatus(Message As String) Handles DvdcdBurner1.BurnStatus
        AddToStatus("BurnStatus:" & Message)
    End Sub

    Private Sub DvdcdBurner1_BurnValidating() Handles DvdcdBurner1.BurnValidating
        AddToStatus("BurnValidating")
    End Sub

    Private Sub DvdcdBurner1_BurnVerifying() Handles DvdcdBurner1.BurnVerifying
        AddToStatus("BurnVerifying")
    End Sub

    ''' <summary>
    ''' Check the license.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdOrderLicense_Click(sender As Object, e As EventArgs) Handles cmdOrderLicense.Click

        ' In order to get your own UserName and RegKey and to distribute this library
        ' with your own projects for commercial or any other purpose, please order a license at:
        ' https://www.microncode.com/developers/cs-dvd-cd-burner/?cmd=order

        System.Diagnostics.Process.Start("https://www.microncode.com/developers/cs-dvd-cd-burner/?cmd=order")

    End Sub

End Class
